@@ -6,12 +6,11 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KONTACTINTERFACE_UNIQUEAPPHANDLER_H
-#define KONTACTINTERFACE_UNIQUEAPPHANDLER_H
+#pragma once
 
 #include "kontactinterface_export.h"
 #include "plugin.h"
-
+#include <memory>
 class QCommandLineParser;
 
 namespace KontactInterface
@@ -58,8 +57,8 @@ protected:
     virtual int activate(const QStringList &args, const QString &workingDirectory);
 
 private:
-    class Private;
-    Private *const d;
+    class UniqueAppHandlerPrivate;
+    std::unique_ptr<UniqueAppHandlerPrivate> const d;
 };
 
 /// Base class for UniqueAppHandler
@@ -119,10 +118,9 @@ private Q_SLOTS:
     void slotApplicationRemoved(const QString &name, const QString &oldOwner, const QString &newOwner);
 
 private:
-    class Private;
-    Private *const d;
+    class UniqueAppWatcherPrivate;
+    std::unique_ptr<UniqueAppWatcherPrivate> const d;
 };
 
 } // namespace
 
-#endif
